==> cheroot-6.3.1.tar.gz: cheroot-6.3.1/.github/ISSUE_TEMPLATE/Bug_report.md <==
---
name: "\U0001F41B Bug report"
about: Create a report to help us improve

---

<!--
Thanks for filing an issue!  Please keep keep issues limited to bug reports,
feature requests, and other general issues. For support questions, please feel
free to reach out on stackoverflow:
https://stackoverflow.com/questions/tagged/cheroot+or+cherrypy
-->
**I'm submitting a ...**
- [X] bug report
- [ ] feature request
- [ ] question about the decisions made in the repository

**Describe the bug. What is the current behavior?**
<!--
A clear and concise description of what the bug is.
-->

**What is the motivation / use case for changing the behavior?**


**To Reproduce**
<!--
Please provide the steps to reproduce and if possible a screenshots and logs of the problem. If you can, show us your code.
-->
Steps to reproduce the behavior:
1. Run '...'
2. Make request '....'
3. See error

**Expected behavior**
<!--
A clear and concise description of what you expected to happen.
-->

**Details**
<!--
If applicable, add tracebacks/logs to help explain your problem.
-->

**Environment**
<!--
Please complete the following information:
-->
- Cheroot version: X.X.X
- CherryPy version: X.X.X (if applicable)
- Python version: 3.6.X
- OS: XXX
- Browser: [all | Chrome XX | Firefox XX | IE XX | Safari XX | Mobile Chrome XX | Android X.X Web Browser | iOS XX Safari | iOS XX UIWebView | iOS XX WKWebView ]

**Additional context**
<!--
Add any other context about the problem here.
(e.g. detailed explanation, tracebacks, related issues, suggestions how to fix, links for us to have context, e.g. stackoverflow, gitter, etc.)
-->

==> cheroot-8.2.1.tar.gz: cheroot-8.2.1/.github/ISSUE_TEMPLATE/Bug_report.md <==
---
name: "\U0001F41B Bug report"
about: Create a report to help us improve

---

<!--
Thanks for filing an issue!  Please keep keep issues limited to bug reports,
feature requests, and other general issues. For support questions, please feel
free to reach out on stackoverflow:
https://stackoverflow.com/questions/tagged/cheroot+or+cherrypy
-->
❓ **I'm submitting a ...**
- [X] 🐞 bug report
- [ ] 🐣 feature request
- [ ] ❓ question about the decisions made in the repository

🐞 **Describe the bug. What is the current behavior?**
<!--
A clear and concise description of what the bug is.
-->

❓ **What is the motivation / use case for changing the behavior?**


💡 **To Reproduce**
<!--
Please provide the steps to reproduce and if possible a screenshots and logs of the problem. If you can, show us your code.
-->
Steps to reproduce the behavior:
1. Run '...'
2. Make request '....'
3. See error

💡 **Expected behavior**
<!--
A clear and concise description of what you expected to happen.
-->

📋 **Details**
<!--
If applicable, add tracebacks/logs to help explain your problem.
-->

📋 **Environment**
<!--
Please complete the following information:
-->
- Cheroot version: X.X.X
- CherryPy version: X.X.X (if applicable)
- Python version: 3.6.X
- OS: XXX
- Browser: [all | Chrome XX | Firefox XX | IE XX | Safari XX | Mobile Chrome XX | Android X.X Web Browser | iOS XX Safari | iOS XX UIWebView | iOS XX WKWebView ]

📋 **Additional context**
<!--
Add any other context about the problem here.
(e.g. detailed explanation, tracebacks, related issues, suggestions how to fix, links for us to have context, e.g. stackoverflow, gitter, etc.)
-->
